@@ -115,7 +115,7 @@ uint32_t dlx_setPC(VM *vm, unsigned int PC)
 
     old = vm->PC;
 
-    DEBUG(DBG_BDPLUS,"[dlx] setPC (%p, %08X -> %08X)\n", vm, old, PC);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] setPC (%p, %08X -> %08X)\n", vm, old, PC);
 
     vm->PC = PC;
 
@@ -130,7 +130,7 @@ uint32_t dlx_setPC(VM *vm, unsigned int PC)
 uint32_t dlx_getPC(VM *vm)
 {
 
-    DEBUG(DBG_BDPLUS,"[dlx] getPC (%p): %08X\n", vm, vm->PC);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] getPC (%p): %08X\n", vm, vm->PC);
     return vm->PC;
 
 }
@@ -142,7 +142,7 @@ int32_t dlx_setWD(VM *vm, int32_t WD)
 
     old = vm->WD;
 
-    DEBUG(DBG_BDPLUS,"[dlx] setWD (%p, %08X -> %08X)\n", vm, old, WD);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] setWD (%p, %08X -> %08X)\n", vm, old, WD);
 
     vm->WD = WD;
     return old;
@@ -153,7 +153,7 @@ int32_t dlx_setWD(VM *vm, int32_t WD)
 int32_t dlx_getWD(VM *vm)
 {
 
-    DEBUG(DBG_BDPLUS,"[dlx] getWD (%p): %08X\n", vm, vm->WD);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] getWD (%p): %08X\n", vm, vm->WD);
     return vm->WD;
 
 }
@@ -164,7 +164,7 @@ uint32_t dlx_setIF(VM *vm, uint32_t IF)
 
     old = vm->IF;
 
-    DEBUG(DBG_BDPLUS,"[dlx] setIF (%p, %08X -> %08X)\n", vm, old, IF);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] setIF (%p, %08X -> %08X)\n", vm, old, IF);
 
     vm->IF = IF;
     return old;
@@ -175,7 +175,7 @@ uint32_t dlx_setIF(VM *vm, uint32_t IF)
 uint32_t dlx_getIF(VM *vm)
 {
 
-    DEBUG(DBG_BDPLUS,"[dlx] getIF (%p): %08X\n", vm, vm->IF);
+    BD_DEBUG(DBG_BDPLUS,"[dlx] getIF (%p): %08X\n", vm, vm->IF);
     return vm->IF;
 
 }
@@ -216,7 +216,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
     vm->trap = 0;
 
     if (flags != BD_STEP_I) {
-        DEBUG(DBG_DLX,"[dlx] running VM %p\n", vm);
+        BD_DEBUG(DBG_DLX,"[dlx] running VM %p\n", vm);
     }
 
     do {
@@ -244,13 +244,13 @@ int32_t dlx_run(VM *vm, int32_t flags)
         case 0x3D: // NOP
         case 0x3E: // NOP
         case 0x3F: // NOP
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): NOP\n", vm->PC-4, C);
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): NOP\n", vm->PC-4, C);
             vm->WD-=1;
             break;
 
         case 0x01: // ADD   | R-type | Rd = Rs1 + Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ADD (R%-2d = R%-2d + R%-2d): %d = %d + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ADD (R%-2d = R%-2d + R%-2d): %d = %d + %d\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]+vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] + vm->R[s2];
@@ -259,7 +259,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x02: // SUB   | R-type | Rd = Rs1 - Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SUB (R%-2d = R%-2d - R%-2d): %08X = %08X - %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SUB (R%-2d = R%-2d - R%-2d): %08X = %08X - %08X\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]-vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] - vm->R[s2];
@@ -268,7 +268,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x03: // MUL   | R-type | Rd = Rs1 * Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): MUL (R%-2d = R%-2d * R%-2d): %08X = %08X * %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): MUL (R%-2d = R%-2d * R%-2d): %08X = %08X * %08X\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]*vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] * vm->R[s2];
@@ -277,7 +277,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x04: // DIV   | R-type | Rd = signed(Rs1) / signed(Rs2)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): DIV (R%-2d = R%-2d / R%-2d): %08X = %08X / %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): DIV (R%-2d = R%-2d / R%-2d): %08X = %08X / %08X\n"
                    , vm->PC-4, C,
                   d,s1,s2,(vm->R[s2] ? (int32_t)vm->R[s1]/(int32_t)vm->R[s2] : 0),vm->R[s1],vm->R[s2]);
             if (vm->R[s2])
@@ -289,7 +289,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x05: // DIVU  | R-type | Rd = unsigned(Rs1) / unsigned(Rs2)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): DIVU(R%-2d = R%-2d / R%-2d): %08X = %08X / %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): DIVU(R%-2d = R%-2d / R%-2d): %08X = %08X / %08X\n"
                    , vm->PC-4, C,
                   d,s1,s2,(vm->R[s2] ? vm->R[s1]/vm->R[s2] : 0),vm->R[s1],vm->R[s2]);
             if (vm->R[s2])
@@ -301,7 +301,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x06: // SLL   | R-type | Rd = Rs1 << (Rs2 & 0x1F)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLL (R%-2d = R%-2d << R%-2d): %08X = %08X << %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLL (R%-2d = R%-2d << R%-2d): %08X = %08X << %d\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]<<(vm->R[s2]&0x1F),vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] << (vm->R[s2]&0x1F);
@@ -310,7 +310,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x07: // SRL   | R-type | Rd = Rs1 >> (Rs2 & 0x1F)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRL (R%-2d = R%-2d >> R%-2d): %08X = %08X >> %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRL (R%-2d = R%-2d >> R%-2d): %08X = %08X >> %d\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]>>(vm->R[s2]&0x1F),vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] >> (vm->R[s2]&0x1F);
@@ -319,7 +319,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x08: // SRA   | R-type | SRL and SRA perform identically if Rs1 is positive. If Rs1 is negative (bit 31 == 1), 1's are shifted in from the left for SRA and SRAI.
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRA (R%-2d = R%-2d >> R%-2d): %08X = %08X >> %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRA (R%-2d = R%-2d >> R%-2d): %08X = %08X >> %d\n"
                    , vm->PC-4, C,
                    d,s1,s2,(int32_t)vm->R[s1]>>(vm->R[s2]&0x1F),vm->R[s1],vm->R[s2]);
             vm->R[d] = (int32_t)vm->R[s1] >> (vm->R[s2]&0x1F);
@@ -328,7 +328,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x09: // AND   | R-type | Rd = Rs1 & Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): AND (R%-2d = R%-2d & R%-2d): %08X = %08X & %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): AND (R%-2d = R%-2d & R%-2d): %08X = %08X & %08X\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]&vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] & vm->R[s2];
@@ -337,7 +337,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0A: // OR    | R-type | Rd = Rs1 | Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): OR  (R%-2d = R%-2d | R%-2d): %08X = %08X | %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): OR  (R%-2d = R%-2d | R%-2d): %08X = %08X | %08X\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]|vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] | vm->R[s2];
@@ -346,7 +346,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0B: // XOR   | R-type | Rd = Rs1 ^ Rs2
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): XOR (R%-2d = R%-2d ^ R%-2d): %08X = %08X ^ %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): XOR (R%-2d = R%-2d ^ R%-2d): %08X = %08X ^ %08X\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]^vm->R[s2],vm->R[s1],vm->R[s2]);
             vm->R[d] = vm->R[s1] ^ vm->R[s2];
@@ -355,7 +355,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0C: // SEQ   | R-type | Rd = (Rs1 == Rs2 ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SEQ (R%-2d = (R%-2d == R%-2d)): %08X = (%08X == %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SEQ (R%-2d = (R%-2d == R%-2d)): %08X = (%08X == %d)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]==vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] == vm->R[s2] ? 1 : 0;
@@ -364,7 +364,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0D: // SNE   | R-type | Rd = (Rs1 != Rs2 ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SNE (R%-2d = (R%-2d != R%-2d)): %08X = (%08X != %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SNE (R%-2d = (R%-2d != R%-2d)): %08X = (%08X != %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]!=vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] != vm->R[s2] ? 1 : 0;
@@ -373,7 +373,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0E: // SLT   | R-type | Rd = (Rs1 < Rs2 ? 1 : 0) [signed]
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLT (R%-2d = (R%-2d < R%-2d)): %08X = (%08X < %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLT (R%-2d = (R%-2d < R%-2d)): %08X = (%08X < %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,(int32_t)vm->R[s1]<(int32_t)vm->R[s2] ? 1 : 0,
                    vm->R[s1], vm->R[s2]);
@@ -383,7 +383,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x0F: // SBT   | R-type | Rd = (Rs1 < Rs2 ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBT (R%-2d = (R%-2d < R%-2d)): %08X = (%08X < %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBT (R%-2d = (R%-2d < R%-2d)): %08X = (%08X < %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]<vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] < vm->R[s2] ? 1 : 0;
@@ -392,7 +392,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x10: // SGT   | R-type | Rd = (Rs1 > Rs2 ? 1 : 0) [signed]
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGT (R%-2d = (R%-2d > R%-2d)): %08X = (%08X < %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGT (R%-2d = (R%-2d > R%-2d)): %08X = (%08X < %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,(int32_t)vm->R[s1]>(int32_t)vm->R[s2] ? 1 : 0,
                    vm->R[s1], vm->R[s2]);
@@ -402,7 +402,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x11: // SAT   | R-type | Rd = (Rs1 > Rs2 ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAT (R%-2d = (R%-2d > R%-2d)): %08X = (%08X > %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAT (R%-2d = (R%-2d > R%-2d)): %08X = (%08X > %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]>vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] > vm->R[s2] ? 1 : 0;
@@ -411,7 +411,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x12: // SLE   | R-type | Rd = (Rs1 <= Rs2 ? 1 : 0) [signed]
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLE (R%-2d = (R%-2d <= R%-2d)): %08X = (%08X <= %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLE (R%-2d = (R%-2d <= R%-2d)): %08X = (%08X <= %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,(int32_t)vm->R[s1]<=(int32_t)vm->R[s2] ? 1 : 0,
                    vm->R[s1], vm->R[s2]);
@@ -421,7 +421,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x13: // SBE   | R-type | Rd =(unsigned(Rs1) <= unsigned(Rs2) ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBE (R%-2d = (R%-2d <= R%-2d)): %08X = (%08X <= %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBE (R%-2d = (R%-2d <= R%-2d)): %08X = (%08X <= %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]<=vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] <= vm->R[s2] ? 1 : 0;
@@ -430,7 +430,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x14: // SGE   | R-type | Rd = (Rs1 >= Rs2 ? 1 : 0) [signed]
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGE (R%-2d = (R%-2d >= R%-2d)): %08X = (%08X >= %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGE (R%-2d = (R%-2d >= R%-2d)): %08X = (%08X >= %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,(int32_t)vm->R[s1]>=(int32_t)vm->R[s2] ? 1 : 0,
                    vm->R[s1], vm->R[s2]);
@@ -440,7 +440,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x15: // SAE   | R-type | Rd =(unsigned(Rs1) >= unsigned(Rs2) ? 1 : 0)
             OP_RTYPE(I, d, s1, s2);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAE (R%-2d = (R%-2d >= R%-2d)): %08X = (%08X >= %08X)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAE (R%-2d = (R%-2d >= R%-2d)): %08X = (%08X >= %08X)\n"
                    , vm->PC-4, C,
                    d,s1,s2,vm->R[s1]>=vm->R[s2] ? 1 : 0, vm->R[s1], vm->R[s2]);
             vm->R[d] = vm->R[s1] >= vm->R[s2] ? 1 : 0;
@@ -449,7 +449,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x16: // JR    | I-type | PC = Rs1
             s1 = OPERAND_S1(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JR  (PC = R%-2d): PC=%08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JR  (PC = R%-2d): PC=%08X\n"
                    , vm->PC-4, C,
                    s1,vm->R[s1] & ADDR_MASK4);
             vm->PC = vm->R[s1] & ADDR_MASK4;
@@ -458,7 +458,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x17: // JALR  | I-type | R31 = PC + 4 ; PC = Rs1
             s1 = OPERAND_S1(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JALR(R31 = PC; PC = R%-2d): PC=%08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JALR(R31 = PC; PC = R%-2d): PC=%08X\n"
                    , vm->PC-4, C,
                    s1,vm->R[s1]);
             vm->R[31] = vm->PC;
@@ -468,7 +468,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x18: // ADDIE | I-type | Rd = Rs1 + extend(immediate)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X):ADDIE(R%-2d = R%-2d + %04X): %d = %d + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X):ADDIE(R%-2d = R%-2d + %04X): %d = %d + %d\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,vm->R[s1]+S_Iimm,vm->R[s1],S_Iimm);
             vm->R[d] = vm->R[s1] + S_Iimm;
@@ -477,7 +477,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x19: // ADDI  | I-type | Rd = Rs1 + immediate
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ADDI(R%-2d = R%-2d + %04X): %d = %d + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ADDI(R%-2d = R%-2d + %04X): %d = %d + %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]+U_Iimm,vm->R[s1],U_Iimm);
             vm->R[d] = vm->R[s1] + U_Iimm;
@@ -486,7 +486,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1A: // SUBIE | I-type | Rd = Rs1 - extended(immediate)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X):SUBIE(R%-2d = R%-2d - %04X): %08X = %08X - %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X):SUBIE(R%-2d = R%-2d - %04X): %08X = %08X - %d\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,
                    vm->R[s1] - S_Iimm,
@@ -497,7 +497,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1B: // SUBI  | I-type | Rd = Rs1 - immediate
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SUBI(R%-2d = R%-2d - %04X): %08X = %08X - %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SUBI(R%-2d = R%-2d - %04X): %08X = %08X - %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,
                    vm->R[s1] - U_Iimm,
@@ -508,7 +508,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1C: // SLLI  | I-type | Rd = Rs1 << (immediate & 0x1F)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLLI(R%-2d = R%-2d << %02X): %08X = %08X << %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLLI(R%-2d = R%-2d << %02X): %08X = %08X << %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm&0x1F,vm->R[s1]<<(U_Iimm&0x1F),vm->R[s1],U_Iimm&0x1F);
             vm->R[d] = vm->R[s1] << (U_Iimm&0x1F);
@@ -517,7 +517,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1D: // SRLI  | I-type | Rd = Rs1 >> (immediate & 0x1F)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRLI(R%-2d = R%-2d >> %02X): %08X = %08X >> %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRLI(R%-2d = R%-2d >> %02X): %08X = %08X >> %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm&0x1F,vm->R[s1]>>(U_Iimm&0x1F),vm->R[s1],U_Iimm&0x1F);
             vm->R[d] = vm->R[s1] >> (U_Iimm&0x1F);
@@ -526,7 +526,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1E: //  SRAI  | I-type | as SRLI & sign extend
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRLI(R%-2d = R%-2d >> %04X): %08X = %08X >> %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SRLI(R%-2d = R%-2d >> %04X): %08X = %08X >> %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,(int32_t)vm->R[s1]>>(U_Iimm&0x1F),vm->R[s1],U_Iimm);
             vm->R[d] = (int32_t)vm->R[s1] >> (U_Iimm&0x1F);
@@ -535,7 +535,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x1F: // ANDI  | I-type | Rd = Rs1 & immediate
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ANDI(R%-2d = R%-2d & %04X): %08X = %08X & %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ANDI(R%-2d = R%-2d & %04X): %08X = %08X & %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]&U_Iimm,vm->R[s1],U_Iimm);
             vm->R[d] = vm->R[s1] & U_Iimm;
@@ -544,7 +544,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x20: // ORI   | I-type | Rd = Rs1 | immediate
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ORI (R%-2d = R%-2d | %04X): %08X = %08X | %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): ORI (R%-2d = R%-2d | %04X): %08X = %08X | %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]|U_Iimm,vm->R[s1],U_Iimm);
             vm->R[d] = vm->R[s1] | U_Iimm;
@@ -553,7 +553,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x21: // XORI  | I-type | Rd = Rs1 ^ immediate
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): XORI(R%-2d = R%-2d ^ %04X): %08X = %08X ^ %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): XORI(R%-2d = R%-2d ^ %04X): %08X = %08X ^ %d\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]^U_Iimm,vm->R[s1],U_Iimm);
             vm->R[d] = vm->R[s1] ^ U_Iimm;
@@ -562,7 +562,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x22: // SEQI  | I-type | Rd = (Rs1 == extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SEQI(R%-2d = (R%-2d == %04X)): %08X = (%08X == %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SEQI(R%-2d = (R%-2d == %04X)): %08X = (%08X == %d)\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,vm->R[s1]==(uint32_t)(int32_t)S_Iimm ? 1 : 0, vm->R[s1], S_Iimm);
             vm->R[d] = (vm->R[s1] == (uint32_t)(int32_t)S_Iimm) ? 1 : 0;
@@ -571,7 +571,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x23: // SNEI  | I-type | Rd = (Rs1 != extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SNEI(R%-2d = (R%-2d != %04X)): %08X = (%08X != %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SNEI(R%-2d = (R%-2d != %04X)): %08X = (%08X != %d)\n"
                    , vm->PC-4, C,
                   d,s1,S_Iimm,(int32_t)vm->R[s1]!=(int32_t)S_Iimm ? 1 : 0, vm->R[s1], S_Iimm);
             vm->R[d] = (vm->R[s1] != (uint32_t)(int32_t)S_Iimm) ? 1 : 0;
@@ -580,7 +580,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x24: // SLI   | I-type | Rd = (Rs1 < extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLI (R%-2d = (R%-2d < %04X)): %08X = (%08X < %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLI (R%-2d = (R%-2d < %04X)): %08X = (%08X < %d)\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,(int32_t)vm->R[s1]<S_Iimm ? 1 : 0, vm->R[s1], S_Iimm);
             vm->R[d] = ((int32_t)vm->R[s1] < S_Iimm) ? 1 : 0;
@@ -589,7 +589,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x25: // SBI   | I-type | Rd = (Rs1 < extend(immediate) ? 1 : 0)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBI (R%-2d = (R%-2d < %04X)): %08X = (%08X < %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBI (R%-2d = (R%-2d < %04X)): %08X = (%08X < %d)\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]<U_Iimm ? 1 : 0, vm->R[s1], U_Iimm);
             vm->R[d] = (vm->R[s1] < U_Iimm) ? 1 : 0;
@@ -598,7 +598,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x26: // SGI   | I-type | Rd = (Rs1 > extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGI (R%-2d = (R%-2d > %04X)): %08X = (%08X > %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGI (R%-2d = (R%-2d > %04X)): %08X = (%08X > %d)\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,(int32_t)vm->R[s1]>S_Iimm ? 1 : 0, vm->R[s1], S_Iimm);
             vm->R[d] = ((int32_t)vm->R[s1] > S_Iimm) ? 1 : 0;
@@ -607,7 +607,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x27: // SAI   | I-type | Rd = (Rs1 > extend(immediate) ? 1 : 0)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAI (R%-2d = (R%-2d > %04X)): %08X = (%08X > %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAI (R%-2d = (R%-2d > %04X)): %08X = (%08X > %d)\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]>U_Iimm ? 1 : 0, vm->R[s1], U_Iimm);
             vm->R[d] = (vm->R[s1] > U_Iimm) ? 1 : 0;
@@ -616,7 +616,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x28: // SLEI  | I-type | Rd = (Rs1 <= extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLEI(R%-2d = (R%-2d <= %04X)): %08X = (%08X <= %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SLEI(R%-2d = (R%-2d <= %04X)): %08X = (%08X <= %d)\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,(int32_t)vm->R[s1]<=S_Iimm ? 1 :0, vm->R[s1], S_Iimm);
             vm->R[d] = ((int32_t)vm->R[s1] <= S_Iimm) ? 1 : 0;
@@ -625,7 +625,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x29: // SBEI  | I-type | Rd = (Rs1 <= unsigned(immediate) ? 1 : 0)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBEI(R%-2d = (R%-2d <= %04X)): %08X = (%08X <= %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SBEI(R%-2d = (R%-2d <= %04X)): %08X = (%08X <= %d)\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]<=U_Iimm ? 1 : 0, vm->R[s1], U_Iimm);
             vm->R[d] = (vm->R[s1] <= U_Iimm) ? 1 : 0;
@@ -634,7 +634,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x2A: // SGEI  | I-type | Rd = (Rs1 >= extend(immediate) ? 1 : 0)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGEI (R%-2d = (R%-2d >= %04X)): %08X = (%08X >= %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SGEI (R%-2d = (R%-2d >= %04X)): %08X = (%08X >= %d)\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,(int32_t)vm->R[s1]>=S_Iimm ? 1 :0, vm->R[s1], S_Iimm);
             vm->R[d] = ((int32_t)vm->R[s1] >= S_Iimm) ? 1 : 0;
@@ -643,7 +643,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x2B: // SAEI  | I-type | Rd = (Rs1 >= extend(immediate) ? 1 : 0)
             OP_ITYPE_U(I, d, s1, U_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAEI(R%-2d = (R%-2d >= %04X)): %08X = (%08X >= %d)\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SAEI(R%-2d = (R%-2d >= %04X)): %08X = (%08X >= %d)\n"
                    , vm->PC-4, C,
                    d,s1,U_Iimm,vm->R[s1]>=U_Iimm ? 1 : 0, vm->R[s1], U_Iimm);
             vm->R[d] = (vm->R[s1] >= U_Iimm) ? 1 : 0;
@@ -652,7 +652,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x2C: // J      | J-type | PC += extend(value)
             OP_JTYPE_S(I, S_Jimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): J   (PC += %07X): %08X = %08X + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): J   (PC += %07X): %08X = %08X + %d\n"
                    , vm->PC-4, C,
                    S_Jimm, (vm->PC+S_Jimm)&ADDR_MASK4, vm->PC, S_Jimm);
 
@@ -664,7 +664,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x2D: // JAL   | J-type | R31 = PC + 4 ; PC += extend(value)
             OP_JTYPE_S(I, S_Jimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JAL (R31 = %08X ; PC += %04X): %08X = PC + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): JAL (R31 = %08X ; PC += %04X): %08X = PC + %d\n"
                    , vm->PC-4, C,
                    vm->PC,
                    S_Jimm,
@@ -678,7 +678,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
         case 0x2E: // BEQZ  | I-type | PC += (Rs1 == 0 ? extend(immediate) : 0)
             s1 = OPERAND_S1(I);
             S_Iimm = OPERAND_SI(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): BEQZ(PC += %04X if !R%-2d): %08X = PC + %d if !%d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): BEQZ(PC += %04X if !R%-2d): %08X = PC + %d if !%d\n"
                    , vm->PC-4, C,
                    S_Iimm,
                    s1,
@@ -692,7 +692,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
         case 0x2F: // BNEZ  | I-type | PC += (Rs1 != 0 ? extend(immediate) : 0)
             s1 = OPERAND_S1(I);
             S_Iimm = OPERAND_SI(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): BNEZ(PC += %04X if R%-2d): %08X += %d if %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): BNEZ(PC += %04X if R%-2d): %08X += %d if %d\n"
                    , vm->PC-4, C,
                    S_Iimm, s1, vm->PC, vm->R[s1] ? S_Iimm : 0, vm->R[s1]);
 
@@ -703,7 +703,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
         case 0x30: // LHI   | I-type | Rd = immediate << 16
             d = OPERAND_D(I);
             U_Iimm = OPERAND_UI(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LHI (R%-2d = %04X << 16): %08X = %08X << 16\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LHI (R%-2d = %04X << 16): %08X = %08X << 16\n"
                    , vm->PC-4, C,
                    d, U_Iimm, U_Iimm << 16, U_Iimm);
 
@@ -713,7 +713,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x31: // LBE   | I-type | Rd = extend(MEM[Rs1 + extend(immediate)] && 0xFF)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LBE (R%-2d = [R%-2d + %04X]c): %08X = [%08X + %d]\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LBE (R%-2d = [R%-2d + %04X]c): %08X = [%08X + %d]\n"
                    , vm->PC-4, C,
                    d, s1, S_Iimm,
                    (int8_t)(vm->addr[ (vm->R[s1] + S_Iimm) & ADDR_MASK1 ]&0xff),
@@ -725,7 +725,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x32: // LB    | I-type | Rd = MEM[Rs1 + extend(immediate)]
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LB  (R%-2d = [R%-2d + %04X]c): %08X = %08X + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LB  (R%-2d = [R%-2d + %04X]c): %08X = %08X + %d\n"
                    , vm->PC-4, C,
                    d, s1, S_Iimm, vm->addr[ ( vm->R[s1] + S_Iimm) & ADDR_MASK1 ]&0xff,
                    vm->R[s1], S_Iimm);
@@ -736,7 +736,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x33: // LWE   | I-type | Rd = extend(MEM[Rs1 + extend(immediate)] && 0xFFFF) (?)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LWE (R%-2d = [R%-2d + %04X]s): %08X = %08X + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LWE (R%-2d = [R%-2d + %04X]s): %08X = %08X + %d\n"
                    , vm->PC-4, C,
                    d, s1, S_Iimm, FETCHS2( &vm->addr[ vm->R[s1] + S_Iimm ] ),
                    vm->R[s1], S_Iimm);
@@ -747,7 +747,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x34: // LW    | I-type | Rd = MEM[Rs1 + extend(immediate)] && 0xFFFF)
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LW  (R%-2d = [R%-2d + %04X]s): %08X = %08X + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LW  (R%-2d = [R%-2d + %04X]s): %08X = %08X + %d\n"
                    , vm->PC-4, C,
                    d, s1, S_Iimm, FETCHU2( &vm->addr[ vm->R[s1] + S_Iimm ] ),
                    vm->R[s1], S_Iimm);
@@ -758,7 +758,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x35: // LDW   | I-type | Rd = MEM[Rs1 + extend(immediate)]
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LDW (R%-2d = [R%-2d + %02X]l): %08X = %08X + %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): LDW (R%-2d = [R%-2d + %02X]l): %08X = %08X + %d\n"
                    , vm->PC-4, C,
                    d,s1,S_Iimm,
                    FETCH4( &vm->addr[ ( vm->R[s1] + S_Iimm ) & ADDR_MASK4 ] ),
@@ -770,7 +770,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x36: // SB    | I-type | MEM[Rs1 + extend(immediate)]c = (u_char) Rd
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SB  ([R%-2d + %04X]c = R%-2d): [ %08X + %d ] = %02X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SB  ([R%-2d + %04X]c = R%-2d): [ %08X + %d ] = %02X\n"
                    , vm->PC-4, C,
                    s1, S_Iimm, d,
                    vm->R[s1], S_Iimm, vm->R[d] & 0xFF);
@@ -781,7 +781,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x37: // SW    | I-type | MEM[Rs1 + extend(immediate)]s = (uint16) Rd
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SW  ([R%-2d + %04X]s = R%-2d): [ %08X + %d ] = %04X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SW  ([R%-2d + %04X]s = R%-2d): [ %08X + %d ] = %04X\n"
                    , vm->PC-4, C,
                    s1, S_Iimm, d,
                    vm->R[s1], S_Iimm, vm->R[d] & 0xFFFF);
@@ -792,7 +792,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x38: // SDW   | I-type | MEM[Rs1 + extend(immediate)] = (uint32) Rd
             OP_ITYPE_S(I, d, s1, S_Iimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SDW ([R%-2d + %02X] = R%-2d): %08X = %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): SDW ([R%-2d + %02X] = R%-2d): %08X = %08X\n"
                    , vm->PC-4, C,
                    s1,S_Iimm,d,
                    (vm->R[s1] + S_Iimm) & ADDR_MASK4,
@@ -804,7 +804,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x39: // TRAP  | J-type | trap[immediate]
             OP_JTYPE_U(I, U_Jimm);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): TRAP([%02X]): TRAP %d\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): TRAP([%02X]): TRAP %d\n"
                    , vm->PC-4, C,
                    U_Jimm, U_Jimm);
 
@@ -823,7 +823,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
             if ((vm->WD <= 0) &&
                 !vm->event_processing) {
 
-                DEBUG(DBG_DLX, "[dlx] trap expired WD %08X. WD reset\n", vm->WD);
+                BD_DEBUG(DBG_DLX, "[dlx] trap expired WD %08X. WD reset\n", vm->WD);
                 dlx_setWD(vm, 0xFA0); // 4000
             }
 
@@ -832,7 +832,7 @@ int32_t dlx_run(VM *vm, int32_t flags)
 
         case 0x3A: // INSTF | I-type | IF = Rs1
             s1 = OPERAND_S1(I);
-            DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): INSTF(IF = R%-2d): IF = %08X\n"
+            BD_DEBUG(DBG_DLX,"[dlx] %08X (I=%02X): INSTF(IF = R%-2d): IF = %08X\n"
                    , vm->PC-4, C,
                    s1,
                    vm->R[s1]);
@@ -842,16 +842,16 @@ int32_t dlx_run(VM *vm, int32_t flags)
             break;
 
         default:
-            DEBUG(DBG_DLX,"[dlx] %08X fetch %08X (I=%02X); UNKNOWN\n", vm->PC, I, C);
+            BD_DEBUG(DBG_DLX,"[dlx] %08X fetch %08X (I=%02X); UNKNOWN\n", vm->PC, I, C);
             return -1;
         }
 
         // According to DLX specifications, R0 is always 0, and read-only
-        if (vm->R[0]) DEBUG(DBG_DLX,"[dlx] WARNING R0 (%08X) not 0!\n", vm->R[0]);
+        if (vm->R[0]) BD_DEBUG(DBG_DLX,"[dlx] WARNING R0 (%08X) not 0!\n", vm->R[0]);
         vm->R[0] = 0;
 
         if (vm->WD <= 0) {
-            DEBUG(DBG_DLX,"[dlx] BREAK! PC=%08X. WD=%08X (old R28 %08X, event %d)\n",
+            BD_DEBUG(DBG_DLX,"[dlx] BREAK! PC=%08X. WD=%08X (old R28 %08X, event %d)\n",
                    vm->PC, vm->WD, vm->R[28], vm->event_processing);
 
             // What do we actually do on breaks?
